@@ -9,12 +9,15 @@ from typing import Any, Dict, List
 try:
     from aws_ecs_service.package.action import Action
     from aws_ecs_service.package import cfnresponse
+    from aws_ecs_service.package.response import Response
 except ImportError:
     # Lambda specific import.
     # noinspection PyUnresolvedReferences
     import cfnresponse
     # noinspection PyUnresolvedReferences
     from action import Action
+    # noinspection PyUnresolvedReferences
+    from response import Response
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -43,25 +46,25 @@ def __failed(event, context, data):
     cfnresponse.send(event, context, cfnresponse.FAILED, data)
 
 
-def __create(**kwargs) -> Dict[str, Any]:
+def __create(**kwargs) -> Response:
     response = Action.create(**kwargs)
     logger.info(json.dumps(response, default=lambda o: '<not serializable>'))
     return response
 
 
-def __update(**kwargs) -> Dict[str, Any]:
+def __update(**kwargs) -> Response:
     response = Action.update(**kwargs)
     logger.info(json.dumps(response, default=lambda o: '<not serializable>'))
     return response
 
 
-def __delete(**kwargs) -> Dict[str, Any]:
+def __delete(**kwargs) -> Response:
     response = Action.delete(**kwargs)
     logger.info(json.dumps(response, default=lambda o: '<not serializable>'))
     return response
 
 
-def __handle(event, context):
+def __handle(event, context) -> Response:
     logger.info('Got new request. Event: {}, Context: {}'.format(event, context))
 
     kwargs = event['ResourceProperties']
@@ -71,20 +74,20 @@ def __handle(event, context):
     delete_args = __try_get_key(kwargs, ['onDelete', 'OnDelete', 'ondelete', 'on_delete'])
 
     if event['RequestType'] == 'Delete':
-        return __delete(**create_args)
+        return __delete(**delete_args)
 
     if event['RequestType'] == 'Create':
-        return __create(**update_args)
+        return __create(**create_args)
 
     if event['RequestType'] == 'Update':
-        return __update(**delete_args)
+        return __update(**update_args)
 
     raise KeyError('Unsupported request type! Type: {}'.format(event['RequestType']))
 
 
 def handler(event, context):
     try:
-        response = __handle(event, context)
+        response = __handle(event, context).to_dict()
     except ClientError as ex:
         return __failed(event, context, {'Error': str(ex.response)})
     except Exception as ex:
